==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSocketCommunicator.java <==
// java wrapper for vtkSocketCommunicator object
//

package vtk;
import vtk.*;

public class vtkSocketCommunicator extends vtkCommunicator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int WaitForConnection_2(int id0);
  public int WaitForConnection(int id0)
    { return WaitForConnection_2(id0); }

  private native int WaitForConnection_3(vtkServerSocket id0,int id1);
  public int WaitForConnection(vtkServerSocket id0,int id1)
    { return WaitForConnection_3(id0,id1); }

  private native void CloseConnection_4();
  public void CloseConnection()
    { CloseConnection_4(); }

  private native int ConnectTo_5(String id0,int id1);
  public int ConnectTo(String id0,int id1)
    { return ConnectTo_5(id0,id1); }

  private native int GetSwapBytesInReceivedData_6();
  public int GetSwapBytesInReceivedData()
    { return GetSwapBytesInReceivedData_6(); }

  private native int GetIsConnected_7();
  public int GetIsConnected()
    { return GetIsConnected_7(); }

  private native void SetNumberOfProcesses_8(int id0);
  public void SetNumberOfProcesses(int id0)
    { SetNumberOfProcesses_8(id0); }

  private native void Barrier_9();
  public void Barrier()
    { Barrier_9(); }

  private native void SetPerformHandshake_10(int id0);
  public void SetPerformHandshake(int id0)
    { SetPerformHandshake_10(id0); }

  private native int GetPerformHandshakeMinValue_11();
  public int GetPerformHandshakeMinValue()
    { return GetPerformHandshakeMinValue_11(); }

  private native int GetPerformHandshakeMaxValue_12();
  public int GetPerformHandshakeMaxValue()
    { return GetPerformHandshakeMaxValue_12(); }

  private native void PerformHandshakeOn_13();
  public void PerformHandshakeOn()
    { PerformHandshakeOn_13(); }

  private native void PerformHandshakeOff_14();
  public void PerformHandshakeOff()
    { PerformHandshakeOff_14(); }

  private native int GetPerformHandshake_15();
  public int GetPerformHandshake()
    { return GetPerformHandshake_15(); }

  private native int LogToFile_16(String id0);
  public int LogToFile(String id0)
    { return LogToFile_16(id0); }

  private native int LogToFile_17(String id0,int id1);
  public int LogToFile(String id0,int id1)
    { return LogToFile_17(id0,id1); }

  private native void SetReportErrors_18(int id0);
  public void SetReportErrors(int id0)
    { SetReportErrors_18(id0); }

  private native int GetReportErrors_19();
  public int GetReportErrors()
    { return GetReportErrors_19(); }

  private native long GetSocket_20();
  public vtkClientSocket GetSocket() {
    long temp = GetSocket_20();

    if (temp == 0) return null;
    return (vtkClientSocket)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSocket_21(vtkClientSocket id0);
  public void SetSocket(vtkClientSocket id0)
    { SetSocket_21(id0); }

  private native int Handshake_22();
  public int Handshake()
    { return Handshake_22(); }

  private native int ServerSideHandshake_23();
  public int ServerSideHandshake()
    { return ServerSideHandshake_23(); }

  private native int ClientSideHandshake_24();
  public int ClientSideHandshake()
    { return ClientSideHandshake_24(); }

  private native int GetIsServer_25();
  public int GetIsServer()
    { return GetIsServer_25(); }

  private native int GetVersion_26();
  public int GetVersion()
    { return GetVersion_26(); }

  private native void BufferCurrentMessage_27();
  public void BufferCurrentMessage()
    { BufferCurrentMessage_27(); }

  private native boolean HasBufferredMessages_28();
  public boolean HasBufferredMessages()
    { return HasBufferredMessages_28(); }

  public vtkSocketCommunicator() { super(); }

  public vtkSocketCommunicator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-7-aarch64.pkg.tar.xz: vtk/vtkSocketCommunicator.java <==
// java wrapper for vtkSocketCommunicator object
//

package vtk;
import vtk.*;

public class vtkSocketCommunicator extends vtkCommunicator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int WaitForConnection_2(int id0);
  public int WaitForConnection(int id0)
    { return WaitForConnection_2(id0); }

  private native int WaitForConnection_3(vtkServerSocket id0,int id1);
  public int WaitForConnection(vtkServerSocket id0,int id1)
    { return WaitForConnection_3(id0,id1); }

  private native void CloseConnection_4();
  public void CloseConnection()
    { CloseConnection_4(); }

  private native int ConnectTo_5(String id0,int id1);
  public int ConnectTo(String id0,int id1)
    { return ConnectTo_5(id0,id1); }

  private native int GetSwapBytesInReceivedData_6();
  public int GetSwapBytesInReceivedData()
    { return GetSwapBytesInReceivedData_6(); }

  private native int GetIsConnected_7();
  public int GetIsConnected()
    { return GetIsConnected_7(); }

  private native void SetNumberOfProcesses_8(int id0);
  public void SetNumberOfProcesses(int id0)
    { SetNumberOfProcesses_8(id0); }

  private native void Barrier_9();
  public void Barrier()
    { Barrier_9(); }

  private native void SetPerformHandshake_10(int id0);
  public void SetPerformHandshake(int id0)
    { SetPerformHandshake_10(id0); }

  private native int GetPerformHandshakeMinValue_11();
  public int GetPerformHandshakeMinValue()
    { return GetPerformHandshakeMinValue_11(); }

  private native int GetPerformHandshakeMaxValue_12();
  public int GetPerformHandshakeMaxValue()
    { return GetPerformHandshakeMaxValue_12(); }

  private native void PerformHandshakeOn_13();
  public void PerformHandshakeOn()
    { PerformHandshakeOn_13(); }

  private native void PerformHandshakeOff_14();
  public void PerformHandshakeOff()
    { PerformHandshakeOff_14(); }

  private native int GetPerformHandshake_15();
  public int GetPerformHandshake()
    { return GetPerformHandshake_15(); }

  private native int LogToFile_16(String id0);
  public int LogToFile(String id0)
    { return LogToFile_16(id0); }

  private native int LogToFile_17(String id0,int id1);
  public int LogToFile(String id0,int id1)
    { return LogToFile_17(id0,id1); }

  private native void SetReportErrors_18(int id0);
  public void SetReportErrors(int id0)
    { SetReportErrors_18(id0); }

  private native int GetReportErrors_19();
  public int GetReportErrors()
    { return GetReportErrors_19(); }

  private native long GetSocket_20();
  public vtkClientSocket GetSocket() {
    long temp = GetSocket_20();

    if (temp == 0) return null;
    return (vtkClientSocket)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSocket_21(vtkClientSocket id0);
  public void SetSocket(vtkClientSocket id0)
    { SetSocket_21(id0); }

  private native int Handshake_22();
  public int Handshake()
    { return Handshake_22(); }

  private native int ServerSideHandshake_23();
  public int ServerSideHandshake()
    { return ServerSideHandshake_23(); }

  private native int ClientSideHandshake_24();
  public int ClientSideHandshake()
    { return ClientSideHandshake_24(); }

  private native int GetIsServer_25();
  public int GetIsServer()
    { return GetIsServer_25(); }

  private native int GetVersion_26();
  public int GetVersion()
    { return GetVersion_26(); }

  private native void BufferCurrentMessage_27();
  public void BufferCurrentMessage()
    { BufferCurrentMessage_27(); }

  private native boolean HasBufferredMessages_28();
  public boolean HasBufferredMessages()
    { return HasBufferredMessages_28(); }

  public vtkSocketCommunicator() { super(); }

  public vtkSocketCommunicator(long id) { super(id); }
  public native long   VTKInit();

}
